# DO NOT SOURCE THIS SCRIPT DIRECTLY!
# USE 'env_unstable.sh', 'env_stable-updates.sh' OR OTHER VARIANTS.

# set environment
DEVTOOLS_ROOT=$(dirname $(dirname ${BASH_SOURCE}))

# all
PATH=${DEVTOOLS_ROOT}/bin:${DEVTOOLS_ROOT}/bin/maint:$PATH
export PATH

PYTHONPATH=${DEVTOOLS_ROOT}/lib:$PYTHONPATH
export PYTHONPATH

# init lmod if necessary
module list > /dev/null 2>&1
ok_mod=$?
if [ ${ok_mod} -ne 0 ] && [ -f /etc/profile.d/lmod.sh ]; then
    . /etc/profile.d/lmod.sh
fi

# Variables for further scripts:
#   machine identifier: DEVTOOLS_COMPUTER_ID
#   asrun installation root: ASTER_ROOT
#   installation root: ASTER_INSTALLROOT
#   options to pass to waf: WAFOPTS

# alias pour thg en Python2
alias thg='PYTHONPATH= thg'

# to use if different variants are supported
variant=
if [ $# -ne 0 ]; then
    variant=$1
fi

# aster5
fident=/home/rd-ap-simumeca/etc/codeaster/aster5
if [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f $fident ]; then
    DEVTOOLS_COMPUTER_ID=aster5
    ASTER_INSTALLROOT=/home/rd-ap-simumeca
    ASTER_ROOT=${ASTER_INSTALLROOT}
    export JOBS=8
    . $ASTER_ROOT/etc/codeaster/profile.sh
    export SBATCH_WCKEY=P10WB:ASTER
fi

# eole
fident=/projets/simumeca/etc/codeaster/eole
if [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f $fident ]; then
    DEVTOOLS_COMPUTER_ID=eole
    ASTER_INSTALLROOT=/projets/simumeca
    ASTER_ROOT=${ASTER_INSTALLROOT}
    ASTER_ETC=$ASTER_ROOT/etc
    . $ASTER_ROOT/etc/codeaster/profile.sh
# To be able to submit a job with Slurn on ATHOS and EOLE
    export SBATCH_WCKEY=P10WB:ASTER
    export SLURM_WCKEY=P10WB:ASTER
fi

# gaia
fident=/projets/simumeca/etc/codeaster/gaia
if [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f $fident ]; then
    DEVTOOLS_COMPUTER_ID=gaia
    if [ "$variant" = "gcc" ]; then
        DEVTOOLS_COMPUTER_ID=gaia_gcc
    fi
    ASTER_INSTALLROOT=/projets/simumeca
    ASTER_ROOT=${ASTER_INSTALLROOT}
    ASTER_ETC=$ASTER_ROOT/etc
    . $ASTER_ROOT/etc/codeaster/profile.sh
fi

# calibre9
if [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ `egrep "Calibre 9|Debian GNU/Linux 8" /etc/issue | wc -l` -eq 1 ]; then
    # use prerequisites installed by user
    fident=$HOME/dev/codeaster-prerequisites/${ASTER_BRANCH_ID}/salome_prerequisites.sh
    if [ "$variant" = "user" ] || [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f "$fident" ]; then
        DEVTOOLS_COMPUTER_ID=calibre9_user
        # for 'admin' account
        [ `whoami` = "rd-ap-simumeca" ] && ASTER_INSTALLROOT=$HOME
        #ASTER_ROOT=
        . $fident
    fi

    if [ -z "$DEVTOOLS_COMPUTER_ID" ]; then
        printf "\n--------------------------------------------------------------\n"
        printf "WARNING: Prerequisites not found for Calibre9!\n"
        printf "    No such directory:\n"
        printf "        $HOME/dev/codeaster-prerequisites/${ASTER_BRANCH_ID}\n\n"
        printf "    You probably need to install them before to continue.\n"
        printf -- "--------------------------------------------------------------\n"
    fi
fi

# scibian9
if [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ `egrep "Scibian 9.0" /etc/issue | wc -l` -eq 1 ]; then
    # use prerequisites installed by user
    fident=$HOME/dev/codeaster-prerequisites/${ASTER_BRANCH_ID}/salome_prerequisites.sh
    if [ "$variant" = "user" ] || [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f "$fident" ]; then
        DEVTOOLS_COMPUTER_ID=scibian9_user
        # for 'admin' account
        [ `whoami` = "aster" ] && ASTER_INSTALLROOT=$HOME
        #ASTER_ROOT=
        . $fident
    fi

    if [ -z "$DEVTOOLS_COMPUTER_ID" ]; then
        printf "\n--------------------------------------------------------------\n"
        printf "WARNING: Prerequisites not found for Scibian9!\n"
        printf "    No such directory:\n"
        printf "        $HOME/dev/codeaster-prerequisites/${ASTER_BRANCH_ID}\n\n"
        printf "    You probably need to install them before to continue.\n"
        printf -- "--------------------------------------------------------------\n"
    fi
fi

# clap0f0q
fident=/home/aster/etc/codeaster/clap0f0q
if [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f $fident ]; then
    DEVTOOLS_COMPUTER_ID=clap0f0q
    ASTER_INSTALLROOT=/home/aster
    ASTER_ROOT=${ASTER_INSTALLROOT}
    export PATH=/usr/local/bin:${PATH}
    export LANG=fr_FR.utf8
    . $ASTER_ROOT/etc/codeaster/profile.sh
fi

# --- other linux with prerequisites package installed
# use prerequisites installed by user
fident=$HOME/dev/codeaster-prerequisites/${ASTER_BRANCH_ID}/salome_prerequisites.sh
if [ "$variant" = "linux" ] || [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f "$fident" ]; then
    DEVTOOLS_COMPUTER_ID=linux
    #ASTER_ROOT=
    . $fident
fi
# try to use prerequisites from a Salome-Meca installation
fident=${USE_SALOME}/salome_prerequisites.sh
if [ "$variant" = "salome" ] || [ -z "$DEVTOOLS_COMPUTER_ID" ] && [ -f "$fident" ]; then
    DEVTOOLS_COMPUTER_ID=linux
    #ASTER_ROOT=
    . $fident
fi

export DEVTOOLS_COMPUTER_ID
export ASTER_ROOT
export ASTER_INSTALLROOT
