# coding=utf-8

"""This module gives convenient functions to check python source files"""

from functools import partial

from aslint.logger import logger
from aslint.utils import apply_in_sandbox
from aslint.base_checkers import (
    CheckList, MsgList, Report,
    check_filename, check_file_content, check_disabled,
)
import aslint.python.python_checkers as PY
import aslint.common_checkers as COMM


def check_python_loop(args, numthread):
    """Check all the files in 'args'. Return a report of the errors."""
    checklist = CheckList()
    checklist.register(PY.CHECK_LIST)
    checklist.register(COMM.CHECK_LIST)
    func_one = partial(check_python_file, checklist=checklist)
    lrep = apply_in_sandbox(func_one, args, numthread)
    report = Report()
    report.merge(lrep)
    return report


def check_python_file(fname, checklist):
    """Check one file"""
    logger.info(fname)
    lmsg = MsgList()
    lmsg.extend(check_filename(fname, checklist.on_filename()))
    lmsg.extend(check_file_content(fname, checklist.on_content()))
    check_disabled(fname, checklist, lmsg)
    report = Report()
    report.set(fname, lmsg)
    return report
