# coding=utf-8

"""
This module partially emulates `mercurial.ui` features.
"""



import os
import os.path as osp

from aslint.logger import logger
from configparser import ConfigParser

_booleans = {'1': True, 'yes': True, 'true': True, 'on': True, 'always': True,
             '0': False, 'no': False, 'false': False, 'off': False,
             'never': False,
             True: True, False: False}


class ui(object):
    """Emulates the `mercurial.ui.ui` object."""
    _cfg = None

    def __init__(self, force=False):
        if not ui._cfg or force:
            ui._cfg = self._configparser()

    def config(self, section, name, default=None):
        """Return a value from the configuration."""
        if self._cfg.has_option(section, name):
            return self._cfg.get(section, name)
        else:
            return default

    def configbool(self, section, name, default='no'):
        """Return a boolean value from the configuration."""
        value = self.config(section, name, default)
        vbool = _booleans.get(value, None)
        if vbool is None:
            raise ValueError("{0}.{1} is not a boolean ('{2}')"
                             .format(section, name, value))
        return vbool

    def username(self):
        """Return the 'ui.username' value."""
        return self._cfg.get("ui", "username")

    def prompt(self, message, default=None):
        """Read a value from keyboard."""
        answer = input(message)
        return answer or default

    @staticmethod
    def _configparser():
        """Read a reader of the mercurial config files."""
        cfg = ConfigParser()
        cfg.read([osp.join(os.environ.get("HOME", ""), ".hgrc"),
                  osp.join(".hg", "hgrc")])
        return cfg


    def setconfig(self, *args):
        raise NotImplementedError("To be removed!")
